@@ -1,6 +1,6 @@
 import base64
 import binascii
-from urllib import urlencode
+from urllib.parse import urlencode
 
 from Crypto.Cipher import AES
 from django.template.loader import render_to_string
